/*
 * Copyright 2008 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#define _CONDOR_ALLOW_OPEN
#include "condor_common.h"

#include "SubmitterObject.h"

#include "stdint.h"

#include "SubmitterUtils.h"

#include "condor_debug.h"

#include "MgmtConversionMacros.h"


using namespace mrg::grid;


SubmitterObject::SubmitterObject(qpid::management::ManagementAgent *agent,
								 SchedulerObject *_scheduler,
								 const char *name)
{
	uint64_t id;

	mgmtObject = new qmf::mrg::grid::Submitter(agent, this, _scheduler);

	if (!GetSubmitterId(name, id)) {
		EXCEPT("Failed to get id for submitter %s", name);
	}

	agent->addObject(mgmtObject, id);
}


SubmitterObject::~SubmitterObject()
{
	if (mgmtObject) {
		mgmtObject->resourceDestroy();
	}
}


void
SubmitterObject::update(const ClassAd &ad)
{
	MGMT_DECLARATIONS;

	INTEGER(HeldJobs);
	INTEGER(IdleJobs);
	TIME_INTEGER(JobQueueBirthdate);
	STRING(Machine);
	STRING(Name);
	INTEGER(RunningJobs);
	STRING(ScheddName);
}


qpid::management::ManagementObject *
SubmitterObject::GetManagementObject(void) const
{
	return mgmtObject;
}
